==> lxqt-panel_1.1.0.orig.tar.xz: lxqt-panel-1.1.0/plugin-quicklaunch/translations/quicklaunch_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="224"/>
        <source>Drop Error</source>
        <translation>Error al soltar</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="225"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>El archivo/URL «%1» no puede incrustarse de momento en el inicio rápido</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="331"/>
        <source>Drop application
icons here</source>
        <translation>Soltar iconos de
aplicaciones aquí</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + arrastrar y colocar)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Mover a la izquierda</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Mover a la derecha</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Quitar del inicio rápido</translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.2.0.tar.xz: lxqt-panel-1.2.0/plugin-quicklaunch/translations/quicklaunch_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="224"/>
        <source>Drop Error</source>
        <translation>Error al soltar</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="225"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>El archivo/URL «%1» no puede incrustarse de momento en el inicio rápido</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="331"/>
        <source>Drop application
icons here</source>
        <translation>Soltar iconos de
aplicaciones aquí</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + arrastrar y colocar)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Mover a la izquierda</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Mover a la derecha</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Quitar del inicio rápido</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
